#
# spec file for package kf6-kbookmarks
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kbookmarks
# Full KF6 version (e.g. 6.14.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kbookmarks
Version:        6.14.0
Release:        1.1
Summary:        Framework for manipulating bookmarks in XBEL format
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}

%description
This is a framework for accessing and manipulating bookmarks using
the XBEL format.

%package -n libKF6Bookmarks6
Summary:        Framework for manipulating bookmarks in XBEL format
Requires:       kf6-kbookmarks >= %{version}

%description -n libKF6Bookmarks6
This is a framework for accessing and manipulating bookmarks using
the XBEL format.

%package -n libKF6BookmarksWidgets6
Summary:        Framework for manipulating bookmarks in XBEL format
Requires:       kf6-kbookmarks >= %{version}

%description -n libKF6BookmarksWidgets6
This is a framework for accessing and manipulating bookmarks using
the XBEL format.

%package devel
Summary:        Development files for kbookmarks, a XBEL format bookmark manipulation framework
Requires:       libKF6Bookmarks6 = %{version}
Requires:       libKF6BookmarksWidgets6 = %{version}
Requires:       cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}
Requires:       cmake(Qt6Xml) >= %{qt6_version}

%description devel
Development files for kbookmarks, a framework for accessing and
manipulating bookmarks using the XBEL format

%lang_package -n libKF6Bookmarks6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kbookmarks6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6Bookmarks6
%ldconfig_scriptlets -n libKF6BookmarksWidgets6

%files
%{_kf6_debugdir}/kbookmarks.categories
%{_kf6_debugdir}/kbookmarks.renamecategories
%{_kf6_debugdir}/kbookmarkswidgets.categories

%files -n libKF6Bookmarks6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6Bookmarks.so.*

%files -n libKF6BookmarksWidgets6
%{_kf6_libdir}/libKF6BookmarksWidgets.so.*

%files devel
%doc %{_kf6_qchdir}/KF6Bookmarks.*
%doc %{_kf6_qchdir}/KF6BookmarksWidgets.*
%{_kf6_libdir}/libKF6Bookmarks.so
%{_kf6_libdir}/libKF6BookmarksWidgets.so
%{_kf6_cmakedir}/KF6Bookmarks/
%{_kf6_includedir}/KBookmarks/
%{_kf6_includedir}/KBookmarksWidgets/

%files -n libKF6Bookmarks6-lang -f kbookmarks6.lang

%changelog
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Update version to 6.14.0
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * It compiles fine without qt6.9 deprecated methods
  * It compiles fine without kf6.12 deprecated methods
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Add xml/yaml linting
  * CI: Add linux-qt6-next build
  * Update version to 6.11.0
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Remove unimplemented methods
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * ci: add Alpine/musl job
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Port to KStandardActions
  * Add missing include
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * It compiles fine without qt6.7 deprecated methods
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Fix KBookmarkManager::save triggering KDirWatch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kbookmarks
